ScaffoldViewNoteKit class

Inheritance

Constructors

ScaffoldViewNoteKit({Key? key, required String title, required S button00, required S button01, required S button02, required S button03, required S button04, required S button05, required S button06, required S button07, required S button08, required S button09, required S button10, required S button11, required S button12, required S button13, required S button14, required S button15, required S button16, required S button17, required S button18, required S button19, required S button20, required S button21, required S button22, required S button23, required S button24, required S button25, required S button26, required S button27, required S button28, required S button29, required S button30, required S button31, required S button32, required S button33, required S button34, required S button35, required S button36, required S button37, required S button38, required S button39, required S button40, required S button41, required S button42, required S button43, required S button44, required S button45, required S button46, required S button47, required S button48, required S button49, required S button50, required S button51, required S button52, required S button53, required S button54, required S button55, required S button56, required S button57, required S button58, required S button59, required S button60, required S button61, required S button62, required S button63, required S button64, required S button65, required S button66, required S button67, required S button68, required S button69, required S button70, required S button71, required S button72, required S button73, required S button74, required S button75, required S button76, required S button77, required S button78, required S button79, required S button80, required S button81, required S button82, required S button83, required S button84, required S button85, required S button86, required S button87, required S button88, required S button89, required S button90, required S button91, required S button92, required S button93, required S button94, required S button95, required S button96, required S button97, required S button98, required S button99})
const

Properties

button00 → S
final
button01 → S
final
button02 → S
final
button03 → S
final
button04 → S
final
button05 → S
final
button06 → S
final
button07 → S
final
button08 → S
final
button09 → S
final
button10 → S
final
button11 → S
final
button12 → S
final
button13 → S
final
button14 → S
final
button15 → S
final
button16 → S
final
button17 → S
final
button18 → S
final
button19 → S
final
button20 → S
final
button21 → S
final
button22 → S
final
button23 → S
final
button24 → S
final
button25 → S
final
button26 → S
final
button27 → S
final
button28 → S
final
button29 → S
final
button30 → S
final
button31 → S
final
button32 → S
final
button33 → S
final
button34 → S
final
button35 → S
final
button36 → S
final
button37 → S
final
button38 → S
final
button39 → S
final
button40 → S
final
button41 → S
final
button42 → S
final
button43 → S
final
button44 → S
final
button45 → S
final
button46 → S
final
button47 → S
final
button48 → S
final
button49 → S
final
button50 → S
final
button51 → S
final
button52 → S
final
button53 → S
final
button54 → S
final
button55 → S
final
button56 → S
final
button57 → S
final
button58 → S
final
button59 → S
final
button60 → S
final
button61 → S
final
button62 → S
final
button63 → S
final
button64 → S
final
button65 → S
final
button66 → S
final
button67 → S
final
button68 → S
final
button69 → S
final
button70 → S
final
button71 → S
final
button72 → S
final
button73 → S
final
button74 → S
final
button75 → S
final
button76 → S
final
button77 → S
final
button78 → S
final
button79 → S
final
button80 → S
final
button81 → S
final
button82 → S
final
button83 → S
final
button84 → S
final
button85 → S
final
button86 → S
final
button87 → S
final
button88 → S
final
button89 → S
final
button90 → S
final
button91 → S
final
button92 → S
final
button93 → S
final
button94 → S
final
button95 → S
final
button96 → S
final
button97 → S
final
button98 → S
final
button99 → S
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
buttonType({required S button, required BuildContext context}) → Widget
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited